# nltokeniz.py

[![PyPI version](https://badge.fury.io/py/nltokeniz.svg)](https://badge.fury.io/py/nltokeniz)
[![Python versions](https://img.shields.io/pypi/pyversions/nltokeniz.svg)](setup.py)
[![Build Status](https://travis-ci.org/raviqqe/nltokeniz.py.svg?branch=master)](https://travis-ci.org/raviqqe/nltokeniz.py)
[![License](https://img.shields.io/badge/license-unlicense-lightgray.svg)](https://unlicense.org)

Natural language tokenizer for English and Japanese documents in Python


## License

[The Unlicense](https://unlicense.org)
